// pages/order/list.js
import { get } from '../../utils/request'
import { checkNeedLogin, checkNeedBindInstitution, getLoginInfo, doLogin } from '../../utils/login'

Page({
  data: {
    currentTab: 'all', // 当前选中的标签
    orderList: [], // 订单列表
    page: 1,
    pageSize: 10,
    loading: false,
    hasMore: true
  },

  async onLoad(options) {
    // 如果从个人中心跳转过来，设置对应的标签
    if (options.type) {
      this.setData({
        currentTab: options.type
      })
    }
    
    // 检查登录状态并自动登录
    if (checkNeedLogin()) {
      try {
        await doLogin()
      } catch (err) {
        console.error('登录失败：', err)
        wx.showToast({
          title: '登录失败，请重试',
          icon: 'none'
        })
        return
      }
    }

    // 检查机构绑定状态
    if (checkNeedBindInstitution()) {
      wx.navigateTo({
        url: '/pages/user/bind'
      })
      return
    }

    this.getOrderList(true)
  },

  // 切换标签
  switchTab(e) {
    const type = e.currentTarget.dataset.type
    this.setData({
      currentTab: type,
      orderList: [],
      page: 1,
      hasMore: true
    })
    this.getOrderList(true)
  },

  // 获取状态码
  getStatusCode(type) {
    switch (type) {
      case 'pending': return 1
      case 'settled': return 2
      case 'invalid': return 3
      default: return 0
    }
  },

  // 获取订单列表
  async getOrderList(refresh = false) {
    if (this.data.loading || (!this.data.hasMore && !refresh)) return

    // 再次检查登录和绑定状态
    if (checkNeedLogin() || checkNeedBindInstitution()) {
      return
    }

    this.setData({ loading: true })

    try {
      const userInfo = getLoginInfo()
      const res = await get('/api/orders/promoteOrderList', {
        page: refresh ? 1 : this.data.page,
        page_size: this.data.pageSize,
        status: this.getStatusCode(this.data.currentTab),
        user_id: userInfo.id
      })

      if (res.errno === '0' && res.rst) {
        const orderList = res.rst.data.map(item => ({
          id: item.order_id,
          createTime: item.order_create_at,
          status: this.getOrderStatus(item.status),
          statusText: this.getStatusText(item.status),
          goods: {
            id: item.product_id,
            image: item.img,
            name: item.name,
            price: item.money,
            count: 1
          },
          commission: item.rebate,
          settlementTime: item.order_balance_at
        }))

        if (refresh) {
          this.setData({
            orderList,
            page: 2,
            hasMore: orderList.length >= this.data.pageSize
          })
        } else {
          this.setData({
            orderList: [...this.data.orderList, ...orderList],
            page: this.data.page + 1,
            hasMore: orderList.length >= this.data.pageSize
          })
        }
      } else {
        wx.showToast({
          title: res.err || '获取订单列表失败',
          icon: 'none'
        })
      }
    } catch (err) {
      console.error('获取订单列表失败：', err)
      wx.showToast({
        title: '网络错误，请稍后重试',
        icon: 'none'
      })
    } finally {
      this.setData({ loading: false })
    }
  },

  // 获取订单状态
  getOrderStatus(status) {
    switch (status) {
      case 1: return 'pending'
      case 2: return 'settled'
      case 3: return 'invalid'
      default: return 'pending'
    }
  },

  // 获取状态文本
  getStatusText(status) {
    switch (status) {
      case 1: return '待结算'
      case 2: return '已结算'
      case 3: return '已失效'
      default: return '待结算'
    }
  },

  // 加载更多
  loadMore() {
    this.getOrderList()
  },

  // 下拉刷新
  onPullDownRefresh() {
    this.getOrderList(true)
    wx.stopPullDownRefresh()
  },

  // 页面显示时检查登录状态
  async onShow() {
    // 如果需要登录，自动登录
    if (checkNeedLogin()) {
      try {
        await doLogin()
      } catch (err) {
        console.error('登录失败：', err)
        wx.showToast({
          title: '登录失败，请重试',
          icon: 'none'
        })
        return
      }
    }

    // 如果需要绑定机构，跳转到绑定页面
    if (checkNeedBindInstitution()) {
      wx.navigateTo({
        url: '/pages/user/bind'
      })
      return
    }

    // 刷新数据
    this.getOrderList(true)
  }
})