import { request } from './request'

/**
 * 检查是否需要登录
 * @returns {boolean} 返回是否需要登录
 */
export function checkNeedLogin() {
  const userInfo = wx.getStorageSync('userInfo')
  return !userInfo || Object.keys(userInfo).length === 0
}

/**
 * 检查是否需要绑定机构
 * @returns {boolean} 返回是否需要绑定机构
 */
export function checkNeedBindInstitution() {
  const bindStatus = wx.getStorageSync('bindStatus')
  return bindStatus !== 1
}

/**
 * 获取用户详细信息
 * @returns {Promise} 返回用户详细信息的Promise
 */
export function getUserInfo() {
  const userInfo = wx.getStorageSync('userInfo')
  return request({
    url: '/api/promoter/getInfo',
    method: 'POST',
    data: {
      openid: userInfo.openid,
      unionid: userInfo.unionid
    }
  }).then(response => {
    if (response.rst) {
      if(response.rst && response.rst.id){
        wx.setStorageSync('userInfo', response.rst)
      }
      
      wx.setStorageSync('bindStatus', response.rst.bind_status)
      return response.rst
    }
    throw new Error('获取用户详细信息失败')
  })
}

/**
 * 执行登录流程
 * @returns {Promise} 返回登录结果的Promise
 */
export function doLogin() {
  return new Promise((resolve, reject) => {
    // 检查是否需要登录
    if (!checkNeedLogin()) {
      // 如果已登录且已绑定机构，获取用户详细信息
      const bindStatus = wx.getStorageSync('bindStatus')
      if (bindStatus === 1) {
        getUserInfo()
          .then(() => resolve())
          .catch(err => {
            console.error('获取用户详细信息失败:', err)
            resolve()
          })
        return
      }
      resolve()
      return
    }

    wx.login({
      success: (res) => {
        if (res.code) {
          // 获取存储的邀请码
          const inviteCode = wx.getStorageSync('invite_code') || ''
          // 发送code和邀请码到后端获取登录态和openid
          request({
            url: '/api/promoter/login',
            method: 'POST',
            data: {
              code: res.code,
              invite_code: inviteCode
            }
          }).then(response => {
            if (!response.rst) {
              reject(new Error('获取用户信息失败'))
              return
            }

            // 清除邀请码，防止重复使用
            wx.removeStorageSync('invite_code')
            
            // 存储用户信息和登录响应
            wx.setStorageSync('userInfo', response.rst)
            wx.setStorageSync('bindStatus', response.rst.bind_status || 0)
            
            // 如果已绑定机构，获取用户详细信息
            if (response.rst.bind_status === 1) {
              return getUserInfo()
                .then(() => resolve(response))
                .catch(err => {
                  console.error('获取用户详细信息失败:', err)
                  resolve(response)
                })
            }
            
            resolve(response)
          }).catch(err => {
            reject(err)
          })
        } else {
          reject(new Error('登录失败：' + res.errMsg))
        }
      },
      fail: (err) => {
        reject(new Error('微信登录失败：' + err.errMsg))
      }
    })
  })
}

/**
 * 获取存储的登录信息
 * @returns {Object} 返回用户信息
 */
export function getLoginInfo() {
  return wx.getStorageSync('userInfo') || {}
}
