// request.js
const BASE_URL = 'https://shop.wenxingshuju.com'

/**
 * 封装请求方法
 * @param {Object} options 请求配置
 * @returns {Promise} Promise对象
 */
export function request(options) {
  return new Promise((resolve, reject) => {
    const token = wx.getStorageSync('token')
    
    // 构建完整的URL
    const url = `${BASE_URL}${options.url}`
    
    // 如果是GET请求，将参数添加到URL中
    let finalUrl = url
    if (options.method === 'GET' && options.data) {
      const params = Object.keys(options.data)
        .map(key => `${encodeURIComponent(key)}=${encodeURIComponent(options.data[key])}`)
        .join('&')
      finalUrl = `${url}?${params}`
    }

    console.log('发起请求：', {
      url: finalUrl,
      method: options.method,
      data: options.data
    })

    wx.request({
      url: finalUrl,
      method: options.method || 'GET',
      data: options.method === 'GET' ? undefined : options.data,
      header: {
        'content-type': 'application/json',
        'Authorization': token ? `Bearer ${token}` : ''
      },
      success: (res) => {
        console.log('请求成功：', res)
        if (res.statusCode === 200) {
          resolve(res.data)
        } else {
          const error = new Error(res.data.message || '请求失败')
          error.statusCode = res.statusCode
          error.data = res.data
          reject(error)
        }
      },
      fail: (err) => {
        console.error('请求失败：', err)
        const error = new Error(err.errMsg || '网络错误')
        error.original = err
        reject(error)
      },
      complete: () => {
        console.log('请求完成')
      }
    })
  })
}

/**
 * GET请求
 * @param {string} url 请求地址
 * @param {Object} data 请求参数
 * @returns {Promise} Promise对象
 */
export function get(url, data) {
  return request({
    url,
    method: 'GET',
    data
  })
}

/**
 * POST请求
 * @param {string} url 请求地址
 * @param {Object} data 请求参数
 * @returns {Promise} Promise对象
 */
export function post(url, data) {
  return request({
    url,
    method: 'POST',
    data
  })
}

/**
 * 上传文件
 * @param {Object} options 上传配置
 * @returns {Promise} Promise对象
 */
export function uploadFile(options) {
  return new Promise((resolve, reject) => {
    const token = wx.getStorageSync('token')
    
    console.log('开始上传文件，参数:', {
      url: `${BASE_URL}${options.url}`,
      filePath: options.filePath,
      name: options.name
    })

    wx.uploadFile({
      url: `${BASE_URL}${options.url}`,
      filePath: options.filePath,
      name: options.name || 'file',
      formData: options.formData || {},
      header: {
        'Authorization': token ? `Bearer ${token}` : ''
      },
      success: (res) => {
        console.log('上传请求成功，状态码:', res.statusCode)
        console.log('上传请求返回数据:', res.data)
        
        if (res.statusCode === 200) {
          try {
            const data = JSON.parse(res.data)
            console.log('解析后的数据:', data)
            // 检查返回的数据结构
            if (data.errno === '0' && data.rst && data.rst.url) {
              resolve(data.rst)
            } else {
              reject(new Error(data.errmsg || '上传失败'))
            }
          } catch (err) {
            console.error('解析响应数据失败:', err)
            reject(new Error('解析响应数据失败'))
          }
        } else {
          const error = new Error('上传失败，状态码：' + res.statusCode)
          error.statusCode = res.statusCode
          error.data = res.data
          reject(error)
        }
      },
      fail: (err) => {
        console.error('上传请求失败:', err)
        const error = new Error(err.errMsg || '网络错误')
        error.original = err
        reject(error)
      }
    })
  })
}
